Learn R Programming

cricketr (version 0.0.12)

batsman4s6s: Compute and plot a stacked barplot of runs,4s and 6s

Description

Compute and plot a stacked barplot of percentages of runs in (1s,2s and 3s),4s and 6s

Usage

batsman4s6s(frames, names)

Arguments

frames
List of batsman
names
Names of batsman

Value

  • None

Details

More details can be found in my short video tutorial in Youtube https://www.youtube.com/watch?v=q9uMPFVsXsI

References

http://www.espncricinfo.com/ci/content/stats/index.html https://gigadom.wordpress.com/

See Also

batsmanScoringRateODTT, relativeRunsFreqPerfODTT, batsmanPerfBoxHist

Examples

Run this code
# Get or use the <batsman>.csv obtained with getPlayerDataOD()
#sehwag <-getPlayerData(35263,dir="./data", file="sehwag.csv",type="batting", 
#homeOrAway=c(1,2),result=c(1,2,4))

# retrieve the file path of a data file installed with cricketr
pathToFile <- system.file("data", "tendulkar.csv", package = "cricketr")
batsman4s6s(pathToFile, "Sachin Tendulkar")

#Note: This example uses the file tendulkar.csv from the /data directory. However
#you can use any directory as long as the data file exists in that directory.
#The general format is pkg-function(pathToFile,par1,...)

Run the code above in your browser using DataLab