Learn R Programming

cricketr (version 0.0.12)

batsmanPerfHomeAway: This function analyses the performance of the batsman at home and overseas

Description

This function plots the runs scored by the batsman at home and overseas

Usage

batsmanPerfHomeAway(file, name = "A Hitter")

Arguments

file
CSV file of batsman from ESPN Cricinfo obtained with getPlayerDataSp()
name
Name of the batsman

Value

  • None

Details

More details can be found in my short video tutorial in Youtube https://www.youtube.com/watch?v=q9uMPFVsXsI

References

http://www.espncricinfo.com/ci/content/stats/index.html https://gigadom.wordpress.com/

See Also

batsmanMovingAverage batsmanRunsPredict batsmanPerfBoxHist bowlerContributionWonLost

Examples

Run this code
# Get or use the <batsman>.csv obtained with getPlayerData()
#tendulkarSp <-getPlayerDataSp(35320,".","tendulkarsp.csv","batting")

# retrieve the file path of a data file installed with cricketr
pathToFile <- system.file("data", "tendulkarsp.csv", package = "cricketr")
batsmanPerfHomeAway(pathToFile,"Sachin Tendulkar")

# Note: The above example uses the file tendulkar.csv from the /data directory. However
# you can use any directory as long as the data file exists in that directory.
# The general format is pkg-function(pathToFile,par1,...)

Run the code above in your browser using DataLab