Learn R Programming

cricketr (version 0.0.12)

bowlerHistWickets: Plot a histogram of Wicket percentages versus wickets taken

Description

This function computes the percentages of wickets taken versus wickets in the bowler's career

Usage

bowlerHistWickets(file,name="A Googly")

Arguments

file
This is the .csv file obtained with an initial getPlayerData()
name
Name of the bowler

Value

  • None

Details

More details can be found in my short video tutorial in Youtube https://www.youtube.com/watch?v=q9uMPFVsXsI

References

http://www.espncricinfo.com/ci/content/stats/index.html https://gigadom.wordpress.com/

See Also

bowlerWktsFreqPercent relativeBowlingER relativeBowlingPerf

Examples

Run this code
# Get or use the <batsman>.csv obtained with getPlayerData()
#  <- getPlayerData(30176,file="kumble.csv",type="bowling", homeOrAway=c(1,2),result=c(1,2,4))

# Retrieve the file path of a data file installed with cricketr
pathToFile <- system.file("data", "kumble.csv", package = "cricketr")
bowlerHistWickets(pathToFile, "Anil Kumble")

# Note: This example uses the file kumble.csv from the /data directory. However
# you can use any directory as long as the data file exists in that directory.
# The general format is pkg-function(pathToFile,par1,...)

Run the code above in your browser using DataLab