Learn R Programming

cricketr (version 0.0.12)

bowlerWktsRunsPlot: Compute and plot the runs conceded versus the wickets taken

Description

This function creates boxplots on the runs conceded for wickets taken for the bowler

Usage

bowlerWktsRunsPlot(file, name = "A Googly")

Arguments

file
This is the .csv file obtained with an initial getPlayerData()
name
Name of the bowler

Value

  • None

Details

More details can be found in my short video tutorial in Youtube https://www.youtube.com/watch?v=q9uMPFVsXsI

References

http://www.espncricinfo.com/ci/content/stats/index.html https://gigadom.wordpress.com/

See Also

bowlerWktsFreqPercent relativeBowlingER relativeBowlingPerf bowlerHistWickets

Examples

Run this code
# Get or use the <bowler>.csv obtained with getPlayerData()
# a <- getPlayerData(30176,file="kumble.csv",type="batting", homeOrAway=c(1,2),result=c(1,2,4))

# Retrieve the file path of a data file installed with cricketr
pathToFile <- system.file("data", "kumble.csv", package = "cricketr")
bowlerWktsRunsPlot(pathToFile,"Anil Kumble")

# Note: This example uses the file kumble.csv from the /data directory. However
# you can use any directory as long as the data file exists in that directory.
# The general format is pkg-function(pathToFile,par1,...)

Run the code above in your browser using DataLab