Learn R Programming

cricketr (version 0.0.13)

relativeBowlerCumulativeAvgWickets: Relative bowlers cumulative average wickets

Description

This function computes and plots the relative cumulative average wickets of a bowler

Usage

relativeBowlerCumulativeAvgWickets(frames, names)

Arguments

frames
This is a list of .csv files obtained with an initial getPlayerData()
names
A list of Twenty20 bowlers names who need to be compared

Value

None

References

http://www.espncricinfo.com/ci/content/stats/index.html https://gigadom.wordpress.com/

See Also

relativeBatsmanCumulativeAvgRuns relativeBowlerCumulativeAvgEconRate relativeBatsmanCumulativeStrikeRate

Examples

Run this code
## Not run: )
# 
# # Retrieve the file path of a data file installed with cricketr
# kumble <- system.file("data", "kumble.csv", package = "cricketr")
# warne <- system.file("data", "warne.csv", package = "cricketr")
# murali <- system.file("data", "murali.csv", package = "cricketr")
# 
# frames <- list(kumble,warne,murali)
# names <- c("Kumble","Warne","Murali")
# relativeBowlerCumulativeAvgWickets(frames,names)
# ## End(Not run)

Run the code above in your browser using DataLab